Struct Exmax
#[repr(transparent)]pub struct Exmax(pub u32);Tuple Fields
0: u32Implementations
impl Exmax
impl Exmax
pub const fn exmaxch(&self) -> u8
pub const fn exmaxch(&self) -> u8
Extremes detector maximum data channel. These bits contains information about the channel on which the data is stored into EXMAX[23:0]. Bits are cleared by reading of this register.
pub const fn set_exmaxch(&mut self, val: u8)
pub const fn set_exmaxch(&mut self, val: u8)
Extremes detector maximum data channel. These bits contains information about the channel on which the data is stored into EXMAX[23:0]. Bits are cleared by reading of this register.